@@ -1,4 +1,4 @@
-/* $Id: daemonlogger.c,v 1.20 2008/08/28 14:47:33 roesch Exp $ */
+/* $Id: daemonlogger.c,v 1.21 2008/11/24 19:56:48 roesch Exp $ */
 
 /*************** IMPORTANT DAEMONLOGGER LICENSE TERMS **************** 
 * 
@@ -133,6 +133,29 @@
 #define PRUNE_OLDEST_ABSOLUTE   0
 #define PRUNE_OLDEST_IN_RUN     1
 
+/* Fix for broken linux <sys/queue.h> */
+#ifndef HAVE_TAILQFOREACH
+#define _EVENT_DEFINED_TQENTRY
+#define TAILQ_ENTRY(type)                       \
+struct {                                \
+        struct type *tqe_next;  /* next element */          \
+        struct type **tqe_prev; /* address of previous next element */  \
+}
+#define TAILQ_FIRST(head)       ((head)->tqh_first)
+#define TAILQ_END(head)         NULL
+#define TAILQ_NEXT(elm, field)      ((elm)->field.tqe_next)
+#define TAILQ_FOREACH(var, head, field)                 \
+    for((var) = TAILQ_FIRST(head);                  \
+        (var) != TAILQ_END(head);                   \
+        (var) = TAILQ_NEXT(var, field))
+#define TAILQ_INSERT_BEFORE(listelm, elm, field) do {           \
+    (elm)->field.tqe_prev = (listelm)->field.tqe_prev;      \
+    (elm)->field.tqe_next = (listelm);              \
+    *(listelm)->field.tqe_prev = (elm);             \
+    (listelm)->field.tqe_prev = &(elm)->field.tqe_next;     \
+} while (0)
+#endif /* TAILQ_FOREACH */
+
 typedef enum {
     MINUTES=1,
     HOURS,
